@@ -87,7 +87,7 @@ $Step=0;
 # error
 #-------------------------------------------------------
 sub error {
-	print "Error: $_[0].\n";
+	print STDERR "Error: $_[0].\n";
     exit 1;
 }
 
